@@ -252,6 +252,7 @@ class PGIdentifierPreparer_pg8000(PGIdentifierPreparer):
 
 class PGDialect_pg8000(PGDialect):
     driver = "pg8000"
+    supports_statement_cache = True
 
     supports_unicode_statements = True
 
@@ -328,9 +329,9 @@ class PGDialect_pg8000(PGDialect):
         return ([], opts)
 
     def is_disconnect(self, e, connection, cursor):
-        if isinstance(
-            e, self.dbapi.InterfaceError
-        ) and "network  error" in str(e):
+        if isinstance(e, self.dbapi.InterfaceError) and "network error" in str(
+            e
+        ):
             # new as of pg8000 1.19.0 for broken connections
             return True
 
