@@ -1604,13 +1604,16 @@ class _hash_limit_string(compat.text_type):
         return hash(self) == hash(other)
 
 
-def warn(msg):
+def warn(msg, code=None):
     """Issue a warning.
 
     If msg is a string, :class:`.exc.SAWarning` is used as
     the category.
 
     """
+    if code:
+        msg = "%s %s" % (msg, exc.SQLAlchemyError(msg, code=code)._code_str())
+
     warnings.warn(msg, exc.SAWarning, stacklevel=2)
 
 
