@@ -1,71 +1,77 @@
 """
-a series of tests which assert the behavior of moving objects between collections
-and scalar attributes resulting in the expected state w.r.t. backrefs, add/remove
-events, etc.
+a series of tests which assert the behavior of moving objects between
+collections and scalar attributes resulting in the expected state w.r.t.
+backrefs, add/remove events, etc.
 
-there's a particular focus on collections that have "uselist=False", since in these
-cases the re-assignment of an attribute means the previous owner needs an
+there's a particular focus on collections that have "uselist=False", since in
+these cases the re-assignment of an attribute means the previous owner needs an
 UPDATE in the database.
 
 """
 
-from sqlalchemy.testing import assert_raises, assert_raises_message
-from sqlalchemy import Integer, String, ForeignKey, Sequence, exc as sa_exc
-from sqlalchemy.testing.schema import Table
-from sqlalchemy.testing.schema import Column
-from sqlalchemy.orm import mapper, relationship, create_session, \
-    class_mapper, backref, sessionmaker, Session
-from sqlalchemy.orm import attributes, exc as orm_exc
 from sqlalchemy import testing
+from sqlalchemy import text
+from sqlalchemy.orm import attributes
+from sqlalchemy.orm import backref
+from sqlalchemy.orm import mapper
+from sqlalchemy.orm import relationship
+from sqlalchemy.orm import Session
 from sqlalchemy.testing import eq_
-from sqlalchemy.testing import fixtures
+from sqlalchemy.testing import is_
+from sqlalchemy.testing.fixtures import fixture_session
 from test.orm import _fixtures
 
+
 class O2MCollectionTest(_fixtures.FixtureTest):
     run_inserts = None
 
     @classmethod
     def setup_mappers(cls):
-        Address, addresses, users, User = (cls.classes.Address,
-                                cls.tables.addresses,
-                                cls.tables.users,
-                                cls.classes.User)
+        Address, addresses, users, User = (
+            cls.classes.Address,
+            cls.tables.addresses,
+            cls.tables.users,
+            cls.classes.User,
+        )
 
         mapper(Address, addresses)
-        mapper(User, users, properties = dict(
-            addresses = relationship(Address, backref="user"),
-        ))
+        mapper(
+            User,
+            users,
+            properties=dict(addresses=relationship(Address, backref="user")),
+        )
 
     def test_collection_move_hitslazy(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
         a1 = Address(email_address="address1")
         a2 = Address(email_address="address2")
         a3 = Address(email_address="address3")
-        u1= User(name='jack', addresses=[a1, a2, a3])
-        u2= User(name='ed')
+        u1 = User(name="jack", addresses=[a1, a2, a3])
+        u2 = User(name="ed")
         sess.add_all([u1, a1, a2, a3])
         sess.commit()
 
-        #u1.addresses
+        # u1.addresses
 
         def go():
             u2.addresses.append(a1)
             u2.addresses.append(a2)
             u2.addresses.append(a3)
+
         self.assert_sql_count(testing.db, go, 0)
 
     def test_collection_move_preloaded(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
         a1 = Address(email_address="address1")
-        u1 = User(name='jack', addresses=[a1])
+        u1 = User(name="jack", addresses=[a1])
 
-        u2 = User(name='ed')
+        u2 = User(name="ed")
         sess.add_all([u1, u2])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         # load u1.addresses collection
         u1.addresses
@@ -82,13 +88,13 @@ class O2MCollectionTest(_fixtures.FixtureTest):
     def test_collection_move_notloaded(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
         a1 = Address(email_address="address1")
-        u1 = User(name='jack', addresses=[a1])
+        u1 = User(name="jack", addresses=[a1])
 
-        u2 = User(name='ed')
+        u2 = User(name="ed")
         sess.add_all([u1, u2])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         u2.addresses.append(a1)
 
@@ -103,13 +109,13 @@ class O2MCollectionTest(_fixtures.FixtureTest):
     def test_collection_move_commitfirst(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
         a1 = Address(email_address="address1")
-        u1 = User(name='jack', addresses=[a1])
+        u1 = User(name="jack", addresses=[a1])
 
-        u2 = User(name='ed')
+        u2 = User(name="ed")
         sess.add_all([u1, u2])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         # load u1.addresses collection
         u1.addresses
@@ -128,11 +134,11 @@ class O2MCollectionTest(_fixtures.FixtureTest):
     def test_scalar_move_preloaded(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
 
-        u1 = User(name='jack')
-        u2 = User(name='ed')
-        a1 = Address(email_address='a1')
+        u1 = User(name="jack")
+        u2 = User(name="ed")
+        a1 = Address(email_address="a1")
         a1.user = u1
         sess.add_all([u1, u2, a1])
         sess.commit()
@@ -155,11 +161,10 @@ class O2MCollectionTest(_fixtures.FixtureTest):
 
         User, Address = self.classes.User, self.classes.Address
 
-
-        sess = sessionmaker()()
-        u1 = User(name='jack')
-        u2 = User(name='ed')
-        a1 = Address(email_address='a1')
+        sess = fixture_session()
+        u1 = User(name="jack")
+        u2 = User(name="ed")
+        a1 = Address(email_address="a1")
         a1.user = u1
         sess.add_all([u1, u2, a1])
         sess.commit()
@@ -169,6 +174,7 @@ class O2MCollectionTest(_fixtures.FixtureTest):
         # PASSIVE_NO_FETCH flag.
         def go():
             a1.user = u2
+
         self.assert_sql_count(testing.db, go, 0)
 
         assert a1 not in u1.addresses
@@ -177,9 +183,9 @@ class O2MCollectionTest(_fixtures.FixtureTest):
     def test_set_none(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
-        u1 = User(name='jack')
-        a1 = Address(email_address='a1')
+        sess = fixture_session()
+        u1 = User(name="jack")
+        a1 = Address(email_address="a1")
         a1.user = u1
         sess.add_all([u1, a1])
         sess.commit()
@@ -187,20 +193,19 @@ class O2MCollectionTest(_fixtures.FixtureTest):
         # works for None too
         def go():
             a1.user = None
+
         self.assert_sql_count(testing.db, go, 0)
 
         assert a1 not in u1.addresses
 
-
-
     def test_scalar_move_notloaded(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
 
-        u1 = User(name='jack')
-        u2 = User(name='ed')
-        a1 = Address(email_address='a1')
+        u1 = User(name="jack")
+        u2 = User(name="ed")
+        a1 = Address(email_address="a1")
         a1.user = u1
         sess.add_all([u1, u2, a1])
         sess.commit()
@@ -216,11 +221,11 @@ class O2MCollectionTest(_fixtures.FixtureTest):
     def test_scalar_move_commitfirst(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
 
-        u1 = User(name='jack')
-        u2 = User(name='ed')
-        a1 = Address(email_address='a1')
+        u1 = User(name="jack")
+        u2 = User(name="ed")
+        a1 = Address(email_address="a1")
         a1.user = u1
         sess.add_all([u1, u2, a1])
         sess.commit()
@@ -237,32 +242,170 @@ class O2MCollectionTest(_fixtures.FixtureTest):
         assert a1 not in u1.addresses
         assert a1 in u2.addresses
 
+    def test_collection_assignment_mutates_previous_one(self):
+        User, Address = self.classes.User, self.classes.Address
+
+        u1 = User(name="jack")
+        u2 = User(name="ed")
+        a1 = Address(email_address="a1")
+        u1.addresses.append(a1)
+
+        is_(a1.user, u1)
+
+        u2.addresses = [a1]
+
+        eq_(u1.addresses, [])
+
+        is_(a1.user, u2)
+
+    def test_collection_assignment_mutates_previous_two(self):
+        User, Address = self.classes.User, self.classes.Address
+
+        u1 = User(name="jack")
+        a1 = Address(email_address="a1")
+
+        u1.addresses.append(a1)
+
+        is_(a1.user, u1)
+
+        u1.addresses = []
+        is_(a1.user, None)
+
+    def test_del_from_collection(self):
+        User, Address = self.classes.User, self.classes.Address
+
+        u1 = User(name="jack")
+        a1 = Address(email_address="a1")
+
+        u1.addresses.append(a1)
+
+        is_(a1.user, u1)
+
+        del u1.addresses[0]
+
+        is_(a1.user, None)
+
+    def test_del_from_scalar(self):
+        User, Address = self.classes.User, self.classes.Address
+
+        u1 = User(name="jack")
+        a1 = Address(email_address="a1")
+
+        u1.addresses.append(a1)
+
+        is_(a1.user, u1)
+
+        del a1.user
+
+        assert a1 not in u1.addresses
+
+    def test_tuple_assignment_w_reverse(self):
+        User, Address = self.classes.User, self.classes.Address
+
+        u1 = User()
+
+        a1 = Address(email_address="1")
+        a2 = Address(email_address="2")
+        a3 = Address(email_address="3")
+        u1.addresses.append(a1)
+        u1.addresses.append(a2)
+        u1.addresses.append(a3)
+
+        u1.addresses[1], u1.addresses[2] = u1.addresses[2], u1.addresses[1]
+
+        assert a3.user is u1
+
+        eq_(u1.addresses, [a1, a3, a2])
+
+    def test_straight_remove(self):
+        User, Address = self.classes.User, self.classes.Address
+
+        u1 = User()
+
+        a1 = Address(email_address="1")
+        a2 = Address(email_address="2")
+        a3 = Address(email_address="3")
+        u1.addresses.append(a1)
+        u1.addresses.append(a2)
+        u1.addresses.append(a3)
+
+        del u1.addresses[2]
+
+        assert a3.user is None
+        eq_(u1.addresses, [a1, a2])
+
+    def test_append_del(self):
+        User, Address = self.classes.User, self.classes.Address
+
+        u1 = User()
+
+        a1 = Address(email_address="1")
+        a2 = Address(email_address="2")
+        a3 = Address(email_address="3")
+        u1.addresses.append(a1)
+        u1.addresses.append(a2)
+        u1.addresses.append(a3)
+
+        u1.addresses.append(a2)
+        del u1.addresses[1]
+
+        assert a2.user is u1
+        eq_(u1.addresses, [a1, a3, a2])
+
+    def test_bulk_replace(self):
+        User, Address = self.classes.User, self.classes.Address
+
+        u1 = User()
+
+        a1 = Address(email_address="1")
+        a2 = Address(email_address="2")
+        a3 = Address(email_address="3")
+        u1.addresses.append(a1)
+        u1.addresses.append(a2)
+        u1.addresses.append(a3)
+        u1.addresses.append(a3)
+
+        assert a3.user is u1
+
+        u1.addresses = [a1, a2, a1]
+
+        assert a3.user is None
+        eq_(u1.addresses, [a1, a2, a1])
+
 
 class O2OScalarBackrefMoveTest(_fixtures.FixtureTest):
     run_inserts = None
 
     @classmethod
     def setup_mappers(cls):
-        Address, addresses, users, User = (cls.classes.Address,
-                                cls.tables.addresses,
-                                cls.tables.users,
-                                cls.classes.User)
+        Address, addresses, users, User = (
+            cls.classes.Address,
+            cls.tables.addresses,
+            cls.tables.users,
+            cls.classes.User,
+        )
 
         mapper(Address, addresses)
-        mapper(User, users, properties = {
-            'address':relationship(Address, backref=backref("user"), uselist=False)
-        })
+        mapper(
+            User,
+            users,
+            properties={
+                "address": relationship(
+                    Address, backref=backref("user"), uselist=False
+                )
+            },
+        )
 
     def test_collection_move_preloaded(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
         a1 = Address(email_address="address1")
-        u1 = User(name='jack', address=a1)
+        u1 = User(name="jack", address=a1)
 
-        u2 = User(name='ed')
+        u2 = User(name="ed")
         sess.add_all([u1, u2])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         # load u1.address
         u1.address
@@ -282,13 +425,13 @@ class O2OScalarBackrefMoveTest(_fixtures.FixtureTest):
     def test_scalar_move_preloaded(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
         a1 = Address(email_address="address1")
         a2 = Address(email_address="address1")
-        u1 = User(name='jack', address=a1)
+        u1 = User(name="jack", address=a1)
 
         sess.add_all([u1, a1, a2])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         # load a1.user
         a1.user
@@ -306,13 +449,13 @@ class O2OScalarBackrefMoveTest(_fixtures.FixtureTest):
     def test_collection_move_notloaded(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
         a1 = Address(email_address="address1")
-        u1 = User(name='jack', address=a1)
+        u1 = User(name="jack", address=a1)
 
-        u2 = User(name='ed')
+        u2 = User(name="ed")
         sess.add_all([u1, u2])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         # reassign
         u2.address = a1
@@ -328,13 +471,13 @@ class O2OScalarBackrefMoveTest(_fixtures.FixtureTest):
     def test_scalar_move_notloaded(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
         a1 = Address(email_address="address1")
         a2 = Address(email_address="address1")
-        u1 = User(name='jack', address=a1)
+        u1 = User(name="jack", address=a1)
 
         sess.add_all([u1, a1, a2])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         # reassign
         a2.user = u1
@@ -349,13 +492,13 @@ class O2OScalarBackrefMoveTest(_fixtures.FixtureTest):
     def test_collection_move_commitfirst(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
         a1 = Address(email_address="address1")
-        u1 = User(name='jack', address=a1)
+        u1 = User(name="jack", address=a1)
 
-        u2 = User(name='ed')
+        u2 = User(name="ed")
         sess.add_all([u1, u2])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         # load u1.address
         u1.address
@@ -376,13 +519,13 @@ class O2OScalarBackrefMoveTest(_fixtures.FixtureTest):
     def test_scalar_move_commitfirst(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
         a1 = Address(email_address="address1")
         a2 = Address(email_address="address2")
-        u1 = User(name='jack', address=a1)
+        u1 = User(name="jack", address=a1)
 
         sess.add_all([u1, a1, a2])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         # load
         assert a1.user is u1
@@ -393,7 +536,7 @@ class O2OScalarBackrefMoveTest(_fixtures.FixtureTest):
         # backref fires
         assert u1.address is a2
 
-        # didnt work this way tho
+        # didn't work this way tho
         assert a1.user is u1
 
         # moves appropriately after commit
@@ -402,31 +545,36 @@ class O2OScalarBackrefMoveTest(_fixtures.FixtureTest):
         assert a1.user is None
         assert a2.user is u1
 
+
 class O2OScalarMoveTest(_fixtures.FixtureTest):
     run_inserts = None
 
     @classmethod
     def setup_mappers(cls):
-        Address, addresses, users, User = (cls.classes.Address,
-                                cls.tables.addresses,
-                                cls.tables.users,
-                                cls.classes.User)
+        Address, addresses, users, User = (
+            cls.classes.Address,
+            cls.tables.addresses,
+            cls.tables.users,
+            cls.classes.User,
+        )
 
         mapper(Address, addresses)
-        mapper(User, users, properties = {
-            'address':relationship(Address, uselist=False)
-        })
+        mapper(
+            User,
+            users,
+            properties={"address": relationship(Address, uselist=False)},
+        )
 
     def test_collection_move_commitfirst(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
         a1 = Address(email_address="address1")
-        u1 = User(name='jack', address=a1)
+        u1 = User(name="jack", address=a1)
 
-        u2 = User(name='ed')
+        u2 = User(name="ed")
         sess.add_all([u1, u2])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         # load u1.address
         u1.address
@@ -441,35 +589,48 @@ class O2OScalarMoveTest(_fixtures.FixtureTest):
         assert u1.address is None
         assert u2.address is a1
 
+
 class O2OScalarOrphanTest(_fixtures.FixtureTest):
     run_inserts = None
 
     @classmethod
     def setup_mappers(cls):
-        Address, addresses, users, User = (cls.classes.Address,
-                                cls.tables.addresses,
-                                cls.tables.users,
-                                cls.classes.User)
+        Address, addresses, users, User = (
+            cls.classes.Address,
+            cls.tables.addresses,
+            cls.tables.users,
+            cls.classes.User,
+        )
 
         mapper(Address, addresses)
-        mapper(User, users, properties = {
-            'address':relationship(Address, uselist=False,
-                backref=backref('user', single_parent=True,
-                                    cascade="all, delete-orphan"))
-        })
+        mapper(
+            User,
+            users,
+            properties={
+                "address": relationship(
+                    Address,
+                    uselist=False,
+                    backref=backref(
+                        "user",
+                        single_parent=True,
+                        cascade="all, delete-orphan",
+                    ),
+                )
+            },
+        )
 
     def test_m2o_event(self):
         User, Address = self.classes.User, self.classes.Address
 
-        sess = sessionmaker()()
+        sess = fixture_session()
         a1 = Address(email_address="address1")
-        u1 = User(name='jack', address=a1)
+        u1 = User(name="jack", address=a1)
 
         sess.add(u1)
         sess.commit()
         sess.expunge(u1)
 
-        u2= User(name='ed')
+        u2 = User(name="ed")
         # the _SingleParent extension sets the backref get to "active" !
         # u1 gets loaded and deleted
         u2.address = a1
@@ -482,16 +643,23 @@ class M2MCollectionMoveTest(_fixtures.FixtureTest):
 
     @classmethod
     def setup_mappers(cls):
-        keywords, items, item_keywords, Keyword, Item = (cls.tables.keywords,
-                                cls.tables.items,
-                                cls.tables.item_keywords,
-                                cls.classes.Keyword,
-                                cls.classes.Item)
+        keywords, items, item_keywords, Keyword, Item = (
+            cls.tables.keywords,
+            cls.tables.items,
+            cls.tables.item_keywords,
+            cls.classes.Keyword,
+            cls.classes.Item,
+        )
 
-        mapper(Item, items, properties={
-            'keywords':relationship(Keyword, secondary=item_keywords,
-                                    backref='items')
-        })
+        mapper(
+            Item,
+            items,
+            properties={
+                "keywords": relationship(
+                    Keyword, secondary=item_keywords, backref="items"
+                )
+            },
+        )
         mapper(Keyword, keywords)
 
     def test_add_remove_pending_backref(self):
@@ -499,15 +667,15 @@ class M2MCollectionMoveTest(_fixtures.FixtureTest):
 
         Item, Keyword = (self.classes.Item, self.classes.Keyword)
 
-        session = Session(autoflush=False)
+        session = fixture_session(autoflush=False)
 
-        i1 = Item(description='i1')
+        i1 = Item(description="i1")
         session.add(i1)
         session.commit()
 
-        session.expire(i1, ['keywords'])
+        session.expire(i1, ["keywords"])
 
-        k1= Keyword(name='k1')
+        k1 = Keyword(name="k1")
         k1.items.append(i1)
         k1.items.remove(i1)
         eq_(i1.keywords, [])
@@ -517,14 +685,14 @@ class M2MCollectionMoveTest(_fixtures.FixtureTest):
 
         Item, Keyword = (self.classes.Item, self.classes.Keyword)
 
-        session = Session(autoflush=False)
+        session = fixture_session(autoflush=False)
 
-        k1= Keyword(name='k1')
-        i1 = Item(description='i1', keywords=[k1])
+        k1 = Keyword(name="k1")
+        i1 = Item(description="i1", keywords=[k1])
         session.add(i1)
         session.commit()
 
-        session.expire(i1, ['keywords'])
+        session.expire(i1, ["keywords"])
 
         k1.items.remove(i1)
         k1.items.append(i1)
@@ -537,9 +705,9 @@ class M2MCollectionMoveTest(_fixtures.FixtureTest):
 
         session = Session(testing.db, autoflush=False)
 
-        k1 = Keyword(name='k1')
-        k2 = Keyword(name='k2')
-        i1 = Item(description='i1', keywords=[k1])
+        k1 = Keyword(name="k1")
+        k2 = Keyword(name="k2")
+        i1 = Item(description="i1", keywords=[k1])
         session.add(i1)
         session.add(k2)
         session.commit()
@@ -548,40 +716,43 @@ class M2MCollectionMoveTest(_fixtures.FixtureTest):
         # the pending
         # list is still here.
         eq_(
-            set(attributes.instance_state(i1).
-                _pending_mutations['keywords'].added_items),
-            set([k2])
+            set(
+                attributes.instance_state(i1)
+                ._pending_mutations["keywords"]
+                .added_items
+            ),
+            set([k2]),
         )
         # because autoflush is off, k2 is still
         # coming in from pending
         eq_(i1.keywords, [k1, k2])
 
         # prove it didn't flush
-        eq_(session.scalar("select count(*) from item_keywords"), 1)
+        eq_(session.scalar(text("select count(*) from item_keywords")), 1)
 
         # the pending collection was removed
-        assert 'keywords' not in attributes.\
-                                instance_state(i1).\
-                                _pending_mutations
+        assert (
+            "keywords" not in attributes.instance_state(i1)._pending_mutations
+        )
 
     def test_duplicate_adds(self):
         Item, Keyword = (self.classes.Item, self.classes.Keyword)
 
         session = Session(testing.db, autoflush=False)
 
-        k1 = Keyword(name='k1')
-        i1 = Item(description='i1', keywords=[k1])
+        k1 = Keyword(name="k1")
+        i1 = Item(description="i1", keywords=[k1])
         session.add(i1)
         session.commit()
 
         k1.items.append(i1)
         eq_(i1.keywords, [k1, k1])
 
-        session.expire(i1, ['keywords'])
+        session.expire(i1, ["keywords"])
         k1.items.append(i1)
         eq_(i1.keywords, [k1, k1])
 
-        session.expire(i1, ['keywords'])
+        session.expire(i1, ["keywords"])
         k1.items.append(i1)
         eq_(i1.keywords, [k1, k1])
 
@@ -589,35 +760,59 @@ class M2MCollectionMoveTest(_fixtures.FixtureTest):
         session.commit()
         eq_(k1.items, [i1])
 
+    def test_bulk_replace(self):
+        Item, Keyword = (self.classes.Item, self.classes.Keyword)
+
+        k1 = Keyword(name="k1")
+        k2 = Keyword(name="k2")
+        k3 = Keyword(name="k3")
+        i1 = Item(description="i1", keywords=[k1, k2])
+        i2 = Item(description="i2", keywords=[k3])
+
+        i1.keywords = [k2, k3]
+        assert i1 in k3.items
+        assert i2 in k3.items
+        assert i1 not in k1.items
+
+
 class M2MScalarMoveTest(_fixtures.FixtureTest):
     run_inserts = None
 
     @classmethod
     def setup_mappers(cls):
-        keywords, items, item_keywords, Keyword, Item = (cls.tables.keywords,
-                                cls.tables.items,
-                                cls.tables.item_keywords,
-                                cls.classes.Keyword,
-                                cls.classes.Item)
+        keywords, items, item_keywords, Keyword, Item = (
+            cls.tables.keywords,
+            cls.tables.items,
+            cls.tables.item_keywords,
+            cls.classes.Keyword,
+            cls.classes.Item,
+        )
 
-        mapper(Item, items, properties={
-            'keyword':relationship(Keyword, secondary=item_keywords,
-                                    uselist=False,
-                                    backref=backref("item", uselist=False))
-        })
+        mapper(
+            Item,
+            items,
+            properties={
+                "keyword": relationship(
+                    Keyword,
+                    secondary=item_keywords,
+                    uselist=False,
+                    backref=backref("item", uselist=False),
+                )
+            },
+        )
         mapper(Keyword, keywords)
 
     def test_collection_move_preloaded(self):
         Item, Keyword = self.classes.Item, self.classes.Keyword
 
-        sess = sessionmaker()()
+        sess = fixture_session()
 
-        k1 = Keyword(name='k1')
-        i1 = Item(description='i1', keyword=k1)
-        i2 = Item(description='i2')
+        k1 = Keyword(name="k1")
+        i1 = Item(description="i1", keyword=k1)
+        i2 = Item(description="i2")
 
         sess.add_all([i1, i2, k1])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         # load i1.keyword
         assert i1.keyword is k1
@@ -633,14 +828,14 @@ class M2MScalarMoveTest(_fixtures.FixtureTest):
     def test_collection_move_notloaded(self):
         Item, Keyword = self.classes.Item, self.classes.Keyword
 
-        sess = sessionmaker()()
+        sess = fixture_session()
 
-        k1 = Keyword(name='k1')
-        i1 = Item(description='i1', keyword=k1)
-        i2 = Item(description='i2')
+        k1 = Keyword(name="k1")
+        i1 = Item(description="i1", keyword=k1)
+        i2 = Item(description="i2")
 
         sess.add_all([i1, i2, k1])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         i2.keyword = k1
 
@@ -652,14 +847,14 @@ class M2MScalarMoveTest(_fixtures.FixtureTest):
     def test_collection_move_commit(self):
         Item, Keyword = self.classes.Item, self.classes.Keyword
 
-        sess = sessionmaker()()
+        sess = fixture_session()
 
-        k1 = Keyword(name='k1')
-        i1 = Item(description='i1', keyword=k1)
-        i2 = Item(description='i2')
+        k1 = Keyword(name="k1")
+        i1 = Item(description="i1", keyword=k1)
+        i2 = Item(description="i2")
 
         sess.add_all([i1, i2, k1])
-        sess.commit() # everything is expired
+        sess.commit()  # everything is expired
 
         # load i1.keyword
         assert i1.keyword is k1
@@ -672,21 +867,25 @@ class M2MScalarMoveTest(_fixtures.FixtureTest):
         assert i1.keyword is None
         assert i2.keyword is k1
 
+
 class O2MStaleBackrefTest(_fixtures.FixtureTest):
     run_inserts = None
 
     @classmethod
     def setup_mappers(cls):
-        Address, addresses, users, User = (cls.classes.Address,
-                                cls.tables.addresses,
-                                cls.tables.users,
-                                cls.classes.User)
+        Address, addresses, users, User = (
+            cls.classes.Address,
+            cls.tables.addresses,
+            cls.tables.users,
+            cls.classes.User,
+        )
 
         mapper(Address, addresses)
-        mapper(User, users, properties = dict(
-            addresses = relationship(Address, backref="user"),
-        ))
-
+        mapper(
+            User,
+            users,
+            properties=dict(addresses=relationship(Address, backref="user")),
+        )
 
     def test_backref_pop_m2o(self):
         User, Address = self.classes.User, self.classes.Address
@@ -703,21 +902,29 @@ class O2MStaleBackrefTest(_fixtures.FixtureTest):
         assert a1.user is u2
         assert a1 in u2.addresses
 
+
 class M2MStaleBackrefTest(_fixtures.FixtureTest):
     run_inserts = None
 
     @classmethod
     def setup_mappers(cls):
-        keywords, items, item_keywords, Keyword, Item = (cls.tables.keywords,
-                                cls.tables.items,
-                                cls.tables.item_keywords,
-                                cls.classes.Keyword,
-                                cls.classes.Item)
+        keywords, items, item_keywords, Keyword, Item = (
+            cls.tables.keywords,
+            cls.tables.items,
+            cls.tables.item_keywords,
+            cls.classes.Keyword,
+            cls.classes.Item,
+        )
 
-        mapper(Item, items, properties={
-            'keywords':relationship(Keyword, secondary=item_keywords,
-                                    backref='items')
-        })
+        mapper(
+            Item,
+            items,
+            properties={
+                "keywords": relationship(
+                    Keyword, secondary=item_keywords, backref="items"
+                )
+            },
+        )
         mapper(Keyword, keywords)
 
     def test_backref_pop_m2m(self):
