@@ -2,12 +2,13 @@ from sqlalchemy import Column
 from sqlalchemy import inspect
 from sqlalchemy import Integer
 from sqlalchemy import MetaData
+from sqlalchemy import select
 from sqlalchemy import Table
+from sqlalchemy import testing
 from sqlalchemy import util
 from sqlalchemy.ext.hybrid import hybrid_method
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import aliased
-from sqlalchemy.orm import create_session
 from sqlalchemy.orm import mapper
 from sqlalchemy.orm import Session
 from sqlalchemy.orm import synonym
@@ -18,8 +19,10 @@ from sqlalchemy.orm.path_registry import RootRegistry
 from sqlalchemy.testing import assert_raises
 from sqlalchemy.testing import AssertsCompiledSQL
 from sqlalchemy.testing import eq_
+from sqlalchemy.testing import expect_warnings
 from sqlalchemy.testing import fixtures
 from sqlalchemy.testing import is_
+from sqlalchemy.testing.fixtures import fixture_session
 from sqlalchemy.util import compat
 from test.orm import _fixtures
 from .inheritance import _poly_fixtures
@@ -54,6 +57,30 @@ class AliasedClassTest(fixtures.TestBase, AssertsCompiledSQL):
         assert Point.id.__clause_element__().table is table
         assert alias.id.__clause_element__().table is not table
 
+    def test_named_entity(self):
+        class Point(object):
+            pass
+
+        self._fixture(Point)
+
+        alias = aliased(Point, name="pp")
+
+        self.assert_compile(
+            select(alias), "SELECT pp.id, pp.x, pp.y FROM point AS pp"
+        )
+
+    def test_named_selectable(self):
+        class Point(object):
+            pass
+
+        table = self._fixture(Point)
+
+        alias = aliased(table, name="pp")
+
+        self.assert_compile(
+            select(alias), "SELECT pp.id, pp.x, pp.y FROM point AS pp"
+        )
+
     def test_not_instantiatable(self):
         class Point(object):
             pass
@@ -151,7 +178,7 @@ class AliasedClassTest(fixtures.TestBase, AssertsCompiledSQL):
 
         self._fixture(Point)
         alias = aliased(Point)
-        sess = Session()
+        sess = fixture_session()
 
         self.assert_compile(
             sess.query(alias).filter(alias.left_of(Point)),
@@ -177,7 +204,7 @@ class AliasedClassTest(fixtures.TestBase, AssertsCompiledSQL):
         eq_(str(Point.double_x.__clause_element__()), "point.x * :x_1")
         eq_(str(alias.double_x.__clause_element__()), "point_1.x * :x_1")
 
-        sess = Session()
+        sess = fixture_session()
 
         self.assert_compile(
             sess.query(alias).filter(alias.double_x > Point.x),
@@ -210,14 +237,33 @@ class AliasedClassTest(fixtures.TestBase, AssertsCompiledSQL):
         eq_(str(alias.x + 1), "point_1.x + :x_1")
         eq_(str(alias.x_alone + 1), "point_1.x + :x_1")
 
-        is_(Point.x_alone.__clause_element__(), Point.x.__clause_element__())
+        point_mapper = inspect(Point)
+
+        eq_(
+            Point.x_alone._annotations,
+            {
+                "entity_namespace": point_mapper,
+                "parententity": point_mapper,
+                "parentmapper": point_mapper,
+                "proxy_key": "x_alone",
+            },
+        )
+        eq_(
+            Point.x._annotations,
+            {
+                "entity_namespace": point_mapper,
+                "parententity": point_mapper,
+                "parentmapper": point_mapper,
+                "proxy_key": "x",
+            },
+        )
 
         eq_(str(alias.x_alone == alias.x), "point_1.x = point_1.x")
 
         a2 = aliased(Point)
         eq_(str(a2.x_alone == alias.x), "point_1.x = point_2.x")
 
-        sess = Session()
+        sess = fixture_session()
 
         self.assert_compile(
             sess.query(alias).filter(alias.x_alone > Point.x),
@@ -237,7 +283,7 @@ class AliasedClassTest(fixtures.TestBase, AssertsCompiledSQL):
         eq_(str(Point.x_syn), "Point.x_syn")
         eq_(str(alias.x_syn), "AliasedClass_Point.x_syn")
 
-        sess = Session()
+        sess = fixture_session()
         self.assert_compile(
             sess.query(alias.x_syn).filter(alias.x_syn > Point.x_syn),
             "SELECT point_1.x AS point_1_x FROM point AS point_1, point "
@@ -276,7 +322,7 @@ class AliasedClassTest(fixtures.TestBase, AssertsCompiledSQL):
         a2 = aliased(Point)
         eq_(str(a2.x_syn == alias.x), "point_1.x = point_2.x")
 
-        sess = Session()
+        sess = fixture_session()
 
         self.assert_compile(
             sess.query(alias).filter(alias.x_syn > Point.x),
@@ -305,7 +351,7 @@ class AliasedClassTest(fixtures.TestBase, AssertsCompiledSQL):
         eq_(str(Point.double_x.__clause_element__()), "point.x * :x_1")
         eq_(str(alias.double_x.__clause_element__()), "point_1.x * :x_1")
 
-        sess = Session()
+        sess = fixture_session()
 
         self.assert_compile(
             sess.query(alias).filter(alias.double_x > Point.x),
@@ -335,7 +381,7 @@ class AliasedClassTest(fixtures.TestBase, AssertsCompiledSQL):
         eq_(str(Point.double_x.__clause_element__()), "point.x * :x_1")
         eq_(str(alias.double_x.__clause_element__()), "point_1.x * :x_1")
 
-        sess = Session()
+        sess = fixture_session()
 
         self.assert_compile(
             sess.query(alias).filter(alias.double_x > Point.x),
@@ -400,44 +446,54 @@ class AliasedClassTest(fixtures.TestBase, AssertsCompiledSQL):
 class IdentityKeyTest(_fixtures.FixtureTest):
     run_inserts = None
 
-    def test_identity_key_1(self):
+    def _cases():
+        return testing.combinations(
+            (orm_util,),
+            (Session,),
+        )
+
+    @_cases()
+    def test_identity_key_1(self, ormutil):
         User, users = self.classes.User, self.tables.users
 
         mapper(User, users)
 
-        key = orm_util.identity_key(User, [1])
+        key = ormutil.identity_key(User, [1])
         eq_(key, (User, (1,), None))
-        key = orm_util.identity_key(User, ident=[1])
+        key = ormutil.identity_key(User, ident=[1])
         eq_(key, (User, (1,), None))
 
-    def test_identity_key_scalar(self):
+    @_cases()
+    def test_identity_key_scalar(self, ormutil):
         User, users = self.classes.User, self.tables.users
 
         mapper(User, users)
 
-        key = orm_util.identity_key(User, 1)
+        key = ormutil.identity_key(User, 1)
         eq_(key, (User, (1,), None))
-        key = orm_util.identity_key(User, ident=1)
+        key = ormutil.identity_key(User, ident=1)
         eq_(key, (User, (1,), None))
 
-    def test_identity_key_2(self):
+    @_cases()
+    def test_identity_key_2(self, ormutil):
         users, User = self.tables.users, self.classes.User
 
         mapper(User, users)
-        s = create_session()
+        s = fixture_session()
         u = User(name="u1")
         s.add(u)
         s.flush()
-        key = orm_util.identity_key(instance=u)
+        key = ormutil.identity_key(instance=u)
         eq_(key, (User, (u.id,), None))
 
-    def test_identity_key_3(self):
+    @_cases()
+    def test_identity_key_3(self, ormutil):
         User, users = self.classes.User, self.tables.users
 
         mapper(User, users)
 
         row = {users.c.id: 1, users.c.name: "Frank"}
-        key = orm_util.identity_key(User, row=row)
+        key = ormutil.identity_key(User, row=row)
         eq_(key, (User, (1,), None))
 
     def test_identity_key_token(self):
@@ -621,6 +677,31 @@ class PathRegistryTest(_fixtures.FixtureTest):
         is_(p1 != p4, True)
         is_(p1 != p5, True)
 
+    def test_eq_non_path(self):
+        umapper = inspect(self.classes.User)
+        amapper = inspect(self.classes.Address)
+        u_alias = inspect(aliased(self.classes.User))
+        p1 = PathRegistry.coerce((umapper,))
+        p2 = PathRegistry.coerce((umapper, umapper.attrs.addresses))
+        p3 = PathRegistry.coerce((u_alias, umapper.attrs.addresses))
+        p4 = PathRegistry.coerce((u_alias, umapper.attrs.addresses, amapper))
+        p5 = PathRegistry.coerce((u_alias,)).token(":*")
+
+        non_object = 54.1432
+
+        for obj in [p1, p2, p3, p4, p5]:
+            with expect_warnings(
+                "Comparison of PathRegistry to "
+                "<.* 'float'> is not supported"
+            ):
+                is_(obj == non_object, False)
+
+            with expect_warnings(
+                "Comparison of PathRegistry to "
+                "<.* 'float'> is not supported"
+            ):
+                is_(obj != non_object, True)
+
     def test_contains_mapper(self):
         umapper = inspect(self.classes.User)
         amapper = inspect(self.classes.Address)
@@ -968,6 +1049,45 @@ class PathRegistryInhTest(_poly_fixtures._Polymorphic):
             ),
         )
 
+    def test_with_poly_base_two(self):
+        Company = _poly_fixtures.Company
+        Person = _poly_fixtures.Person
+        Engineer = _poly_fixtures.Engineer
+        cmapper = inspect(Company)
+        pmapper = inspect(Person)
+
+        p_poly = with_polymorphic(Person, [Engineer])
+        e_poly_insp = inspect(p_poly.Engineer)  # noqa - used by comment below
+        p_poly_insp = inspect(p_poly)
+
+        p1 = PathRegistry.coerce(
+            (
+                cmapper,
+                cmapper.attrs.employees,
+                p_poly_insp,
+                pmapper.attrs.paperwork,
+            )
+        )
+
+        eq_(
+            p1.path,
+            (
+                cmapper,
+                cmapper.attrs.employees,
+                p_poly_insp,
+                pmapper.attrs.paperwork,
+            ),
+        )
+        eq_(
+            p1.natural_path,
+            (
+                cmapper,
+                cmapper.attrs.employees,
+                pmapper,
+                pmapper.attrs.paperwork,
+            ),
+        )
+
     def test_nonpoly_oftype_aliased_subclass_onroot(self):
         Engineer = _poly_fixtures.Engineer
         eng_alias = aliased(Engineer)
@@ -1051,7 +1171,7 @@ class PathRegistryInhTest(_poly_fixtures._Polymorphic):
             ),
         )
 
-    def test_with_poly_base(self):
+    def test_with_poly_base_one(self):
         Person = _poly_fixtures.Person
         Engineer = _poly_fixtures.Engineer
         pmapper = inspect(Person)
