@@ -1049,6 +1049,10 @@ class DefaultRequirements(SuiteRequirements):
                 except exc.DBAPIError:
                     return False
 
+    @property
+    def sqlite_memory(self):
+        return only_on(self._sqlite_memory_db)
+
     @property
     def reflects_json_type(self):
         return only_on(
